@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dwim-shell-command" "0.62.2"
+(define-package "dwim-shell-command" "20251013.1518"
   "Shell commands with DWIM behaviour."
   '((emacs "28.1"))
   :url "https://github.com/xenodium/dwim-shell-command"
-  :commit "7d1c45aa2bc782c448cadd989dc776c2e5f83514"
-  :revdesc "7d1c45aa2bc7")
+  :commit "5ffad4ac5702e046166d0f59a3d3d790aa8274a2"
+  :revdesc "5ffad4ac5702")
