@@ -5,8 +5,8 @@
 ;; Author: Alvaro Ramirez
 ;; Package-Requires: ((emacs "28.1"))
 ;; URL: https://github.com/xenodium/dwim-shell-command
-;; Package-Version: 0.62.2
-;; Package-Revision: 7d1c45aa2bc7
+;; Package-Version: 20251013.1518
+;; Package-Revision: 5ffad4ac5702
 
 ;; This package is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@ Set to nil to use `shell-command-switch'."
 
 (defcustom dwim-shell-command-done-buffer-name
   (lambda (name)
-    (format "✅ %s %s" name (propertize "done" 'face 'success)))
+    (format "%s %s" name (propertize "done" 'face 'success)))
   "Function to format buffer name on success.
 Use `identify' to remove formatting."
   :type 'function
@@ -99,7 +99,7 @@ Use `identify' to remove formatting."
 
 (defcustom dwim-shell-command-error-buffer-name
   (lambda (name)
-    (format "⛔️ %s %s" name (propertize "error" 'face 'error)))
+    (format "%s %s" name (propertize "error" 'face 'error)))
   "Function to format buffer name on error.
 Use `identify' to remove formatting."
   :type 'function
@@ -938,21 +938,26 @@ all needed to finalize processing."
     (setq dwim-shell-command--commands
           (map-delete dwim-shell-command--commands (process-name process)))))
 
-(cl-defun dwim-shell-command--unique-new-file-path (file-path &key expand)
-  "Return a unique FILE-PATH using :EXPAND to expand FILE-PATH.
+(defun dwim-shell-command--unique-new-file-path (file-path)
+  "Return a unique FILE-PATH.
+
+If FILE-PATH already contains a number in the format (n), set counter to n.
+
 \"/tmp/blah.txt\" -> \"/tmp/blah(1).txt\"
-\"/tmp/blah\" -> \"/tmp/blah(1)\""
-  (let ((counter 1)
-        (name (file-name-sans-extension file-path))
-        (extension (file-name-extension file-path)))
+\"/tmp/blah(2).txt\" -> \"/tmp/blah(3).txt\""
+  (let* ((name (file-name-sans-extension file-path))
+         (extension (file-name-extension file-path))
+         (counter (if (string-match "(\\([0-9]+\\))$" name)
+                      (string-to-number (match-string 1 name))
+                    0)))
+    (when (string-match "(\\([0-9]+\\))$" name)
+      (setq name(replace-match "" t t name)))
     (while (file-exists-p file-path)
-      (if extension
-          (setq file-path (format "%s(%d).%s" name counter extension))
-        (setq file-path (format "%s(%d)" name counter)))
-      (setq counter (1+ counter)))
-    (if expand
-        (expand-file-name file-path)
-      file-path)))
+      (setq counter (1+ counter))
+      (setq file-path (if extension
+                          (format "%s(%d).%s" name counter extension)
+                        (format "%s(%d)" name counter))))
+    file-path))
 
 (defun dwim-shell-command--sentinel (process _)
   "Handles PROCESS sentinel and STATE."
